==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Successfully saved" : "Succesvol opgeslagen",
    "Saving failed:" : "Opslaan mislukt:",
    "File mime type" : "Bestand mime type",
    "is" : "is",
    "is not" : "is niet",
    "matches" : "komt overeen",
    "does not match" : "komt niet overeen",
    "Example: {placeholder}" : "Bijvoorbeeld: {placeholder}",
    "File size (upload)" : "Bestandsgrootte (upload)",
    "less" : "minder",
    "less or equals" : "minder of gelijk",
    "greater or equals" : "groter of gelijk",
    "greater" : "groter",
    "File system tag" : "Bestandssysteem markering",
    "is tagged with" : "is gemarkeerd met",
    "is not tagged with" : "is niet gemarkeerd met",
    "Select tag…" : "Selecteer markering...",
    "Request remote address" : "Vraag extern adres aan",
    "matches IPv4" : "komt overeen met IPv4",
    "does not match IPv4" : "komt niet overeen met IPv4",
    "matches IPv6" : "komt overeen met IPv6",
    "does not match IPv6" : "komt niet overeen met IPv6",
    "Request time" : "Vraag tijd aan",
    "between" : "tussen",
    "not between" : "niet tussen",
    "Start" : "Begin",
    "End" : "Einde",
    "Select timezone…" : "Selecteer tijdzone...",
    "Request URL" : "Vraag URL aan",
    "Predefined URLs" : "Voorgedefinieerde URL's",
    "Files WebDAV" : "Bestanden WebDAV",
    "Request user agent" : "Vraag gebruikersagent aan",
    "Sync clients" : "Synchroniseer clients",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "User group membership" : "Gebruikersgroep lidmaatschap",
    "is member of" : "is lid van",
    "is not member of" : "is geen lid van",
    "The given operator is invalid" : "De opgegeven operator is ongeldig",
    "The given regular expression is invalid" : "De opgegeven reguliere expressie is ongeldig",
    "The given file size is invalid" : "De opgegeven bestandsgrootte is ongeldig",
    "The given tag id is invalid" : "De opgegeven markerings-id is ongeldig",
    "The given IP range is invalid" : "De opgegeven IP-range is ongeldig",
    "The given IP range is not valid for IPv4" : "De opgegeven IP-range is niet geldig voor IPv4",
    "The given IP range is not valid for IPv6" : "De opgegeven IP-range is niet geldig voor IPv6",
    "The given time span is invalid" : "De opgegeven tijdspanne is ongeldig",
    "The given start time is invalid" : "De opgegeven begintijd is ongeldig",
    "The given end time is invalid" : "De opgegeven eindtijd is ongeldig",
    "The given group does not exist" : "De opgegeven groep bestaat niet",
    "Check %s is invalid or does not exist" : "Controleer: %s is ongeldig of bestaat niet",
    "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
    "Operation %s does not exist" : "Bewerking %s bestaat niet",
    "Operation %s is invalid" : "Bewerking %s is ongeldig",
    "Check %s does not exist" : "Controleer: %s bestaat niet",
    "Check %s is invalid" : "Controleer: %s is ongeldig",
    "Check #%s does not exist" : "Controleer: #%s bestaat niet",
    "Workflow" : "Workflow",
    "Open documentation" : "Open documentatie",
    "Add rule group" : "Groepsrol toevoegen",
    "Short rule description" : "Korte rolbeschrijving",
    "Add rule" : "Voeg rol toe",
    "Reset" : "Reset",
    "Save" : "Opslaan",
    "Saving…" : "Opslaan...",
    "Loading…" : "Laden..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saving failed:" : "Opslaan mislukt:",
    "is" : "is",
    "is not" : "is niet",
    "matches" : "komt overeen",
    "does not match" : "komt niet overeen",
    "Example: {placeholder}" : "Bijvoorbeeld: {placeholder}",
    "File size (upload)" : "Bestandsgrootte (upload)",
    "less" : "minder",
    "less or equals" : "minder of gelijk",
    "greater or equals" : "groter of gelijk",
    "greater" : "groter",
    "File system tag" : "Bestandssysteem markering",
    "is tagged with" : "is gemarkeerd met",
    "is not tagged with" : "is niet gemarkeerd met",
    "Select tag…" : "Selecteer markering...",
    "Request remote address" : "Vraag extern adres aan",
    "matches IPv4" : "komt overeen met IPv4",
    "does not match IPv4" : "komt niet overeen met IPv4",
    "matches IPv6" : "komt overeen met IPv6",
    "does not match IPv6" : "komt niet overeen met IPv6",
    "Request time" : "Vraag tijd aan",
    "between" : "tussen",
    "not between" : "niet tussen",
    "Start" : "Begin",
    "End" : "Einde",
    "Select timezone…" : "Selecteer tijdzone...",
    "Request URL" : "Vraag URL aan",
    "Predefined URLs" : "Voorgedefinieerde URL's",
    "Files WebDAV" : "Bestanden WebDAV",
    "Request user agent" : "Vraag gebruikersagent aan",
    "Sync clients" : "Synchroniseer clients",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "User group membership" : "Gebruikersgroep lidmaatschap",
    "is member of" : "is lid van",
    "is not member of" : "is geen lid van",
    "The given operator is invalid" : "De opgegeven operator is ongeldig",
    "The given regular expression is invalid" : "De opgegeven reguliere expressie is ongeldig",
    "The given file size is invalid" : "De opgegeven bestandsgrootte is ongeldig",
    "The given tag id is invalid" : "De opgegeven markerings-id is ongeldig",
    "The given IP range is invalid" : "De opgegeven IP-range is ongeldig",
    "The given IP range is not valid for IPv4" : "De opgegeven IP-range is niet geldig voor IPv4",
    "The given IP range is not valid for IPv6" : "De opgegeven IP-range is niet geldig voor IPv6",
    "The given time span is invalid" : "De opgegeven tijdspanne is ongeldig",
    "The given start time is invalid" : "De opgegeven begintijd is ongeldig",
    "The given end time is invalid" : "De opgegeven eindtijd is ongeldig",
    "The given group does not exist" : "De opgegeven groep bestaat niet",
    "Check %s is invalid or does not exist" : "Controleer: %s is ongeldig of bestaat niet",
    "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
    "Operation %s does not exist" : "Bewerking %s bestaat niet",
    "Operation %s is invalid" : "Bewerking %s is ongeldig",
    "Check %s does not exist" : "Controleer: %s bestaat niet",
    "Check %s is invalid" : "Controleer: %s is ongeldig",
    "Check #%s does not exist" : "Controleer: #%s bestaat niet",
    "Workflow" : "Workflow",
    "Open documentation" : "Open documentatie",
    "Add rule group" : "Groepsrol toevoegen",
    "Short rule description" : "Korte rolbeschrijving",
    "Add rule" : "Voeg rol toe",
    "Reset" : "Reset",
    "Save" : "Opslaan",
    "Saving…" : "Opslaan...",
    "Loading…" : "Laden...",
    "Successfully saved" : "Succesvol opgeslagen",
    "File mime type" : "Bestand mime type"
},
"nplurals=2; plural=(n != 1);");
